@@ -30,7 +30,7 @@ import pygame
 import subprocess
 import re
 
-VERSION = u'8.9.0'
+VERSION = u'9.0.0'
 
 class audio_low_latency_play_init(item):
 
@@ -317,11 +317,11 @@ class audio_low_latency_play_init(item):
                 else:
                     try:
                         self.device = self.device_init.open(format=self.device_init.get_format_from_width(self.samplewidth),
-                                channels=self.channels,
-                                rate=self.samplerate,
-                                output=True,
-                                frames_per_buffer=self.period_size,
-                                output_device_index=self.device_index)
+                                                            channels=self.channels,
+                                                            rate=self.samplerate,
+                                                            output=True,
+                                                            frames_per_buffer=self.period_size,
+                                                            output_device_index=self.device_index)
 
                         self.show_message(u"Audio device opened")
 
@@ -394,7 +394,6 @@ class audio_low_latency_play_init(item):
 
             self.experiment.audio_low_latency_play_device = self.device
             self.experiment.cleanup_functions.append(self.close)
-            self.python_workspace[u'audio_low_latency_play'] = self.experiment.audio_low_latency_play_device
 
 
         elif self.dummy_mode == u'yes':
@@ -421,6 +420,7 @@ class audio_low_latency_play_init(item):
         try:
             self.show_message(u"Closing audio device")
             self.device.close()
+            self.experiment.audio_low_latency_play_device.close()
             if  self.module == self.pyaudio_module_name:
                 self.device.stop_stream()
                 self.device.close()
