@@ -30,7 +30,7 @@ import wave
 import numpy
 import os, re, os.path
 
-VERSION = u'8.9.0'
+VERSION = u'9.0.0'
 
 class audio_low_latency_record(item):
 
@@ -320,15 +320,15 @@ class audio_low_latency_record(item):
         self.kb.flush()
         if self.stop != u'':
             if key1 in self._allowed_responses_stop:
-                self.show_message(u'Stopped audio recording')
+                self.show_message(u'Detected key press for stopping audio')
                 self.record_continue = 0
         if self.pause_resume != u'':
             if key1 in self._allowed_responses_pause_resume:
                 if self.record_execute_pause == 0:
-                    self.show_message(u'Paused audio recording')
+                    self.show_message(u'Detected key press for pausing audio recording')
                     self.record_execute_pause = 1
                 elif self.record_execute_pause == 1:
-                    self.show_message(u'Resumed audio recording')
+                    self.show_message(u'Detected key press for resuming audio recording')
                     self.record_execute_pause = 0
 
     def show_message(self, message):
